import { DepGraph } from '@snyk/dep-graph';
import { legacyPlugin as api } from '@snyk/cli-interface';
import { getGradleAttributesPretty } from './gradle-attributes-pretty';
import { SnykGraph } from './graph';
import type { CoordinateMap, PomCoords, Sha1Map, SnykHttpClient } from './types';
export interface GradleInspectOptions {
    'configuration-matching'?: string;
    'configuration-attributes'?: string;
    daemon?: boolean;
    reachableVulns?: boolean;
    callGraphBuilderTimeout?: number;
    initScript?: string;
    gradleNormalizeDeps?: boolean;
}
declare type Options = api.InspectOptions & GradleInspectOptions;
declare type VersionBuildInfo = api.VersionBuildInfo;
export declare function inspect(root: string, targetFile: string, options?: api.SingleSubprojectInspectOptions & GradleInspectOptions, snykHttpClient?: SnykHttpClient): Promise<api.SinglePackageResult>;
export declare function inspect(root: string, targetFile: string, options: api.MultiSubprojectInspectOptions & GradleInspectOptions, snykHttpClient?: SnykHttpClient): Promise<api.MultiProjectResult>;
export interface JsonDepsScriptResult {
    defaultProject: string;
    projects: ProjectsDict;
    allSubProjectNames: string[];
    versionBuildInfo?: VersionBuildInfo;
    sha1Map?: Sha1Map;
}
interface ProjectsDict {
    [project: string]: GradleProjectInfo;
}
interface GradleProjectInfo {
    depGraph?: DepGraph;
    snykGraph?: SnykGraph;
    targetFile: string;
    projectVersion: string;
}
declare function extractJsonFromScriptOutput(stdoutText: string): JsonDepsScriptResult;
declare function getVersionBuildInfo(gradleVersionOutput: string): VersionBuildInfo | undefined;
export declare function getMavenPackageInfo(sha1: string, depCoords: Partial<PomCoords>, snykHttpClient: SnykHttpClient): Promise<string>;
declare function splitCoordinate(coordinate: string): Partial<PomCoords>;
export declare function processProjectsInExtractedJSON(root: string, extractedJSON: JsonDepsScriptResult, coordinateMap?: CoordinateMap): Promise<JsonDepsScriptResult>;
declare function toCamelCase(input: string): string;
export declare function formatArgWithWhiteSpace(arg: string): string;
declare function buildArgs(root: string, targetFile: string | null, initGradlePath: string, options: Options): string[];
export declare const exportsForTests: {
    buildArgs: typeof buildArgs;
    extractJsonFromScriptOutput: typeof extractJsonFromScriptOutput;
    getVersionBuildInfo: typeof getVersionBuildInfo;
    toCamelCase: typeof toCamelCase;
    getGradleAttributesPretty: typeof getGradleAttributesPretty;
    splitCoordinate: typeof splitCoordinate;
    getMavenPackageInfo: typeof getMavenPackageInfo;
};
export {};
